Improve this Doc

# Error: ngModel:constexpr
Non-Constant Expression

    Expected constant expression for `{0}`, but saw `{1}`.

## Description

Some attributes used in conjunction with ngModel (such as ngTrueValue or ngFalseValue) will only accept constant expressions.

Examples using constant expressions include:

    <input type="checkbox" ng-model="..." ng-true-value="'truthyValue'">
    <input type="checkbox" ng-model="..." ng-false-value="0">

Examples of non-constant expressions include:

    <input type="checkbox" ng-model="..." ng-true-value="someValue">
    <input type="checkbox" ng-model="..." ng-false-value="{foo: someScopeValue}">